<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'info_compresseur_titre' => 'Gwellekaat ha gwaskañ',
	'info_question_activer_compactage_css' => 'Ha c’hoant hoc’h eus ma vefe gwasket ar follennoù stil (CSS) ?', # MODIF
	'info_question_activer_compactage_js' => 'Ha c’hoant hoc’h e vefe gwasket ar skriptoù javascript ?', # MODIF

	// T
	'texte_compacter_avertissement' => 'Diwallit da chom hep gweredekaat an dibarzhioù-mañ e-keit hag emeur o sevel ho lec’hienn : n’hall ket an elfennoù gwasket bezañ lennet ken war-lerc’h.',
	'texte_compacter_script_css' => 'Gallout a ra SPIP gwaskañ ar skriptoù javascript hag ar follennoù-stil CSS, evit o enrollañ er restroù difiñv;  buanoc’h e teu al lec’hienn war wel.',
	'titre_compacter_script_css' => 'Gwaskañ ar furmskridoù hag ar follennoù-stil'
);

?>
